@@ -34,9 +34,7 @@
 void *result_worker(void *);
 int set_worker( gearman_worker_st **worker );
 void *get_results( gearman_job_st *, void *, size_t *, gearman_return_t * );
-#ifdef GM_DEBUG
-void write_debug_file(char ** text);
-#endif
+void reschedule_high_latency(check_result * chk_result);
 
 /**
  * @}
