@@ -1,14 +1,14 @@
 /* return human readable name for neb type */
-char * nebtype2str(int i) {
+char * nebtype2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
 
 /* return human readable name for nebcallback */
-char * nebcallback2str(int i) {
+char * nebcallback2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
 
 /* return human readable name for eventtype */
-char * eventtype2str(int i) {
+char * eventtype2str(__attribute__((__unused__)) int i) {
     return strdup("UNKNOWN");
 }
